from django.db.models import CharField

from paintstore.widgets import ColorPickerWidget


class ColorPickerField(CharField):

    def __init__(self, *args, **kwargs):
        kwargs["max_length"] = 7
        super(ColorPickerField, self).__init__(*args, **kwargs)

    def formfield(self, **kwargs):
        kwargs.update({"widget": ColorPickerWidget})
        return super(ColorPickerField, self).formfield(**kwargs)


try:
    from south.modelsinspector import add_introspection_rules
    add_introspection_rules([], ["^paintstore\.fields\.ColorPickerField"])
except ImportError:
    pass


from django import forms
from django.conf import settings
from django.utils.safestring import mark_safe


class ColorPickerWidget(forms.TextInput):
    class Media:
        css = {
            "all": ("%s/%s" % (settings.STATIC_URL, "paintstore/css/colorpicker.css"),)
        }

        js  = (
            ("%s/%s" % (settings.STATIC_URL, "paintstore/jquery_1.7.2.js")),
            ("%s/%s" % (settings.STATIC_URL, "paintstore/colorpicker.js"))
        )

    input_type = 'colorpicker'

    def render(self, name, value, attrs=None):
        script = u"""<script type='text/javascript'>
                        $(document).ready(function(){
                            $('#%s').ColorPicker({
                                onSubmit: function(hsb, hex, rgb, el, parent) {
                                    $(el).val('#' + hex);
                                    $(el).ColorPickerHide();
                                },
                                onBeforeShow: function () {
                                    $(this).ColorPickerSetColor(this.value);
                                }
                            }).bind('keyup', function(){
                                $(this).ColorPickerSetColor(this.value.replace('#', ''));
                            });
                        });
                    </script>
                    """ % ("id_%s" % name,)

        super_render = super(ColorPickerWidget, self).render(name, value, attrs)
        return mark_safe(u"%s%s" % (super_render, script))



import os
import codecs
import re
from setuptools import setup, find_packages


def read(*parts):
    return codecs.open(os.path.join(os.path.dirname(__file__), *parts)).read()


def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


setup(
    name='django-paintstore',
    version=find_version("paintstore", "__init__.py"),
    description='A Django app that integrates jQuery ColorPicker with the Django admin.',
    long_description=read('README.rst'),
    author='Glenn Siegman',
    author_email='gsiegman@gsiegman.com',
    license='MIT',
    url='https://github.com/gsiegman/django-paintstore',
    packages=find_packages(),
    include_package_data=True,
    zip_safe = False,
    classifiers=[
        "Development Status :: 4 - Beta",
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Utilities',
    ]
)